Learn R Programming

QuantileGH (version 0.1.8)

fmx_normix: Naive Parameter Estimates using Mixture of Normal

Description

Naive parameter estimates for finite mixture distribution fmx using mixture of normal distributions.

Usage

fmx_normix(x, K, distname = c("norm", "GH", "sn"), alpha = 0.05, R = 10L, ...)

Value

Function fmx_normix() returns an fmx object.

Arguments

x

numeric vector, observations

K

integer scalar, number of mixture components

distname

character scalar, name of parametric distribution of the mixture components

alpha

numeric scalar, proportion of observations to be trimmed in trimmed \(k\)-means algorithm tkmeans

R

integer scalar, number of normalmixEM replicates

...

additional parameters, currently not in use

Details

fmx_normix ... the cluster centers are provided as the starting values of \(\mu\)'s for the univariate normal mixture by EM algorithm. R replicates of normal mixture estimates are obtained, and the one with maximum likelihood will be selected