powered by
Test if two double vectors are element-wise (nearly) equal.
allequal_o_(target, current, tolerance = sqrt(.Machine$double.eps), ...)
Function allequal_o_() returns an \(n_t\times n_c\)
allequal_o_()
logical
matrix
indicating whether the length-\(n_c\)
vector
current
is element-wise near-equal to the length-\(n_t\)
target
within the pre-specified tolerance.
tolerance
length-\(n_t\) double vector, the target value(s), missing value not allowed
length-\(n_c\) double vector, the value(s) to be compared with target, missing value not allowed
positive double scalar, default sqrt(.Machine$double.eps)
sqrt(.Machine$double.eps)
potential parameters, currently not in use
Function allequal_o_() is different from all.equal.numeric, such that
only compares between double, not complex, values
element-wise comparison is performed, in a fashion similar to function outer
a logical scalar is always returned for each element-wise comparison.
allequal_o_(target = c(.3, 0), current = c(.3, 1-.7, 0, .Machine$double.eps))
Run the code above in your browser using DataLab