Naive parameter estimates for finite mixture distribution fmx using mixture of normal distributions.
fmx_normix(x, K, distname = c("norm", "GH", "sn"), alpha = 0.05, R = 10L, ...)Function fmx_normix() returns an fmx object.
integer scalar, number of mixture components
character scalar, name of parametric distribution of the mixture components
numeric scalar, proportion of observations to be trimmed in trimmed \(k\)-means algorithm tkmeans
integer scalar, number of normalmixEM replicates
additional parameters, currently not in use
fmx_normix ... the cluster centers are provided as the starting values of \(\mu\)'s for
the univariate normal mixture by EM algorithm.
R replicates of normal mixture estimates are obtained, and
the one with maximum likelihood will be selected